@@ -3,7 +3,17 @@ package XML::Grammar::Fiction;
 use warnings;
 use strict;
 
-=encoding utf8
+
+our $VERSION = '0.11.0';
+
+
+1;
+
+__END__
+
+=pod
+
+=encoding utf-8
 
 =head1 NAME
 
@@ -12,11 +22,7 @@ and a lightweight markup language for stories, novels and other fiction.
 
 =head1 VERSION
 
-Version 0.10.0
-
-=cut
-
-our $VERSION = '0.10.0';
+version 0.11.0
 
 =head1 SYNOPSIS
 
@@ -51,6 +57,12 @@ L<XML::Grammar::Screenplay> .
 
 The rest of this page will document the syntax of the custom textual format.
 
+=encoding utf8
+
+=head1 VERSION
+
+Version 0.11.0
+
 =head1 FORMAT
 
 =head2 Sections
@@ -162,7 +174,6 @@ An unordered list.
 
     </body>
 
-
 =head3 Other Examples
 
 Examples can be found in the C<t/data> directory, and here:
@@ -183,18 +194,6 @@ L<http://www.shlomifish.org/humour/human-hacking/>
 
 =back
 
-=head1 AUTHOR
-
-Shlomi Fish, L<http://www.shlomifish.org/>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-xml-grammar-fiction at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fiction>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
 =head1 MOTIVATION
 
 I (= Shlomi Fish) originated this CPAN distribution (after forking
@@ -211,74 +210,141 @@ so you'll need to accept that some modifications to your sources will be
 required in the future. I hope you still find it useful and let me know
 if you need any feature or bug-fix.
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2007 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction or by email to
+bug-xml-grammar-fiction@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
 =head1 SUPPORT
 
+=head2 Perldoc
+
 You can find documentation for this module with the perldoc command.
 
-    perldoc XML::Grammar::Fiction
+  perldoc XML::Grammar::Fiction
 
-You can also look for information at:
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
 
 =over 4
 
-=item * XML-Grammar-Fiction’s Homepage
+=item *
 
-L<http://www.shlomifish.org/open-source/projects/XML-Grammar/Fiction/>
+MetaCPAN
 
-=item * AnnoCPAN: Annotated CPAN documentation
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://annocpan.org/dist/XML-Grammar-Fiction>
+L<http://metacpan.org/release/XML-Grammar-Fiction>
 
-=item * CPAN Ratings
+=item *
 
-L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
+Search CPAN
 
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction>
-
-=item * MetaCPAN
-
-L<https://metacpan.org/release/XML-Grammar-Fiction>
-
-=item * Search CPAN
+The default CPAN search engine, useful to view POD in HTML format.
 
 L<http://search.cpan.org/dist/XML-Grammar-Fiction>
 
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::Grammar::Fiction>
+
 =back
 
-=head1 ACKNOWLEDGEMENTS
+=head2 Bugs / Feature Requests
 
-=head1 COPYRIGHT & LICENSE
+Please report any bugs or feature requests by email to C<bug-xml-grammar-fiction at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
+progress on the request by the system.
 
-Copyright (c) 2007, 2009 Shlomi Fish.
+=head2 Source Code
 
-This program is released under the following license: MIT X11:
-L<http://www.opensource.org/licenses/mit-license.php> .
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
 
-=head2 LICENSE
+L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
 
-Copyright (c) 2007, 2009 Shlomi Fish.
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-THE SOFTWARE.
+  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
 
 =cut
-
-1;
-
