@@ -8,29 +8,9 @@ extends("XML::Grammar::FictionBase::TagsTree2XML");
 
 my $screenplay_ns = q{http://web-cpan.berlios.de/modules/XML-Grammar-Screenplay/screenplay-xml-0.2/};
 
-=head1 NAME
 
-XML::Grammar::Screenplay::FromProto - module that converts well-formed
-text representing a screenplay to an XML format.
+our $VERSION = '0.11.0';
 
-=head1 VERSION
-
-Version 0.10.0
-
-=cut
-
-our $VERSION = '0.10.0';
-
-=head2 new()
-
-Accepts no arguments so far. May take some time as the grammar is compiled
-at that point.
-
-=head2 meta()
-
-Internal - (to settle pod-coverage.).
-
-=cut
 
 sub _init
 {
@@ -48,11 +28,6 @@ sub _init
     return 0;
 }
 
-=head2 $self->convert({ source => { file => $path_to_file } })
-
-Converts the file $path_to_file to XML and returns it.
-
-=cut
 
 sub _output_tag
 {
@@ -122,6 +97,25 @@ sub _paragraph_tag
     return "para";
 }
 
+sub _handle_elem_of_name_img
+{
+    my ($self, $elem) = @_;
+
+    $self->_output_tag_with_childs(
+        {
+            start => [
+                "image",
+                "url" => $elem->lookup_attr("src"),
+                "alt" => $elem->lookup_attr("alt"),
+                "title" => $elem->lookup_attr("title"),
+            ],
+            elem => $elem,
+        }
+    );
+
+    return;
+}
+
 sub _handle_elem_of_name_a
 {
     my ($self, $elem) = @_;
@@ -300,28 +294,175 @@ sub convert
     return ${$self->_buffer()};
 }
 
+1;
+
+__END__
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+XML::Grammar::Screenplay::FromProto - module that converts well-formed
+text representing a screenplay to an XML format.
+
+=head1 VERSION
+
+version 0.11.0
+
+=head1 VERSION
+
+Version 0.11.0
+
+=head2 new()
+
+Accepts no arguments so far. May take some time as the grammar is compiled
+at that point.
+
+=head2 meta()
+
+Internal - (to settle pod-coverage.).
+
+=head2 $self->convert({ source => { file => $path_to_file } })
+
+Converts the file $path_to_file to XML and returns it.
+
 =head1 AUTHOR
 
-Shlomi Fish, L<http://www.shlomifish.org/>.
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2007 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =head1 BUGS
 
-Please report any bugs or feature requests to
-C<bug-xml-grammar-fiction at rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fiction>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction or by email to
+bug-xml-grammar-fiction@rt.cpan.org.
 
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
-=head1 ACKNOWLEDGEMENTS
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
-=head1 COPYRIGHT & LICENSE
+=head1 SUPPORT
 
-Copyright 2007 Shlomi Fish, all rights reserved.
+=head2 Perldoc
 
-This program is released under the following license: MIT X11.
+You can find documentation for this module with the perldoc command.
+
+  perldoc XML::Grammar::Fiction
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/XML-Grammar-Fiction>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=XML-Grammar-Fiction>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/XML-Grammar-Fiction>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.perl.org/dist/overview/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/X/XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=XML-Grammar-Fiction>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=XML::Grammar::Fiction>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-xml-grammar-fiction at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=XML-Grammar-Fiction>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<http://bitbucket.org/shlomif/perl-XML-Grammar-Fiction>
+
+  hg clone ssh://hg@bitbucket.org/shlomif/perl-XML-Grammar-Fiction
 
 =cut
-
-1;
-
